Welcome to python-vaporetto's documentation!
============================================

`Vaporetto`_ is a fast and lightweight pointwise prediction based tokenizer. This is a Python
wrapper for Vaporetto.

.. _Vaporetto: https://github.com/daac-tools/vaporetto

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   examples
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
